@@ -2,8 +2,7 @@ package Sub::Regex;
 
 use 5.006;
 use strict;
-use warnings;
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 require Exporter;
 use AutoLoader;
 our @EXPORT = qw/AUTOLOAD/;
@@ -27,10 +26,15 @@ sub AUTOLOAD{
     use vars '$AUTOLOAD';
     $AUTOLOAD =~ /(.+)::/;
     my $pkg = $1;
-    for my $k (keys %Regs){
-	goto &{"$pkg"."::${Regprefix}".$Regs{$k}} if ( $AUTOLOAD =~ /$k/i );
+    if ($' eq 'DESTROY'){
+	goto &{"$pkg::DESTROY"};
+    }
+    else{
+	for my $k (keys %Regs){
+	    goto &{"$pkg"."::${Regprefix}".$Regs{$k}} if ( $AUTOLOAD =~ /$k/i );
+	}
+	die "Can't translate your sub << $AUTOLOAD >>\n";
     }
-    die "Can't translate your sub << $AUTOLOAD >>\n";
 }
 
 
